@@ -21,6 +21,8 @@ from scanpydoc.elegant_typehints.return_tuple import process_docstring
 
 TestCls = type("Class", (), {})
 TestCls.__module__ = "_testmod"
+TestExc = type("Excep", (RuntimeError,), {})
+TestExc.__module__ = "_testmod"
 
 
 @pytest.fixture
@@ -31,7 +33,10 @@ def app(make_app_setup) -> Sphinx:
             "sphinx_autodoc_typehints",
             "scanpydoc.elegant_typehints",
         ],
-        qualname_overrides={"_testmod.Class": "test.Class"},
+        qualname_overrides={
+            "_testmod.Class": "test.Class",
+            "_testmod.Excep": "test.Excep",
+        },
     )
 
 
@@ -137,11 +142,16 @@ def test_literal(app):
     )
 
 
-def test_qualname_overrides(app):
+def test_qualname_overrides_class(app):
     assert TestCls.__module__ == "_testmod"
     assert _format_terse(TestCls) == ":py:class:`~test.Class`"
 
 
+def test_qualname_overrides_exception(app):
+    assert TestExc.__module__ == "_testmod"
+    assert _format_terse(TestExc) == ":py:exception:`~test.Excep`"
+
+
 def test_qualname_overrides_recursive(app):
     assert _format_terse(t.Union[TestCls, str]) == (
         r":py:class:`~test.Class`, :py:class:`str`"
